@@ -2,9 +2,8 @@ from django.utils.translation import ugettext_lazy as _
 from django.db import models
 from imagekit.models import ImageSpecField, ProcessedImageField
 from imagekit.processors import ResizeToFit, SmartResize, Adjust
-from upy.utils import today
+from datetime import date
 from django.conf import settings
-from project import config
 from upy.contrib.g11n.models import G11nModel
 
 def _choose_preprocessor():
@@ -60,7 +59,7 @@ class PositionImage(UPYImage):
         abstract = True   
             
             
-if config.USE_UPY_G11N:
+if settings.USE_UPY_G11N:
         
     class UPYImageG11n(G11nModel):
         """
@@ -75,7 +74,7 @@ if config.USE_UPY_G11N:
         class Meta:
             abstract = True
 
-if config.USE_UPY_IMAGE:            
+if settings.USE_UPY_IMAGE:            
     class ImageRepositoryBase(PositionImage):
         """
         Concrete class for Images. It add useful fields like position, name, date... and manage position
@@ -83,7 +82,7 @@ if config.USE_UPY_IMAGE:
         """
         name = models.CharField(max_length=100)
         display_image = ImageSpecField([ResizeToFit(800,600)], image_field='original_image', options={'quality': 90})  #format='JPEG',
-        date = models.DateField(default = today(), help_text = _(u"Set the date you want to display for this image.")) 
+        date = models.DateField(default = date.today, help_text = _(u"Set the date you want to display for this image.")) 
         creation_date = models.DateTimeField(auto_now_add = True, help_text = _(u"Establishment date"), 
                                              verbose_name = _(u"Creation date"))
         def admin_thumbnail_view(self):
@@ -111,7 +110,7 @@ if config.USE_UPY_IMAGE:
             abstract = True
     
         
-    if config.USE_UPY_G11N:
+    if settings.USE_UPY_G11N:
         
                 
         class ImageRepositoryG11n(UPYImageG11n):
